@@ -45,17 +45,33 @@
 
 typedef struct
         {
-         int     val;
-         int     x;
-         int     y;
-         int     active;
-         int     team;
-         int     loose_time;
-         int     score_order;
-         int     color_entry;
-         int     key_state;
-         int     cpu_or_human;
-         int     from_network;
+         int     val;           /* value which will be used when the*/
+                                /* will be put into the map. this   */
+                                /* value decreases at each round.   */
+         int     x;             /* x position of the cursor         */
+         int     y;             /* y position of the cursor         */
+         int     active;        /* true if the player who owns this */
+                                /* cursor is playing with it        */
+         int     team;          /* team the cursor belongs to       */
+         int     loose_time;    /* time at which this cursor has    */
+                                /* lost. it seems that the diff     */
+                                /* between cursor and team is not   */
+                                /* well defined 8-(                 */
+         int     score_order;   /* wether you are 1st or 2nd...     */
+         int     color_entry;   /* first color used by this cursor  */
+                                /* in the 256 color palette. again  */
+                                /* a cursor is associated to a team */
+         int     key_state;     /* this value holds the state of all*/
+                                /* the keys associated to the cursor*/
+                                /* it is a logical or between       */
+                                /* - CURSOR_KEY_UP                  */
+                                /* - CURSOR_KEY_RIGHT               */
+                                /* - CURSOR_KEY_DOWN                */
+                                /* - CURSOR_KEY_LEFT                */
+                                /* which are defined in move.h      */
+         int     cpu_or_human;  /* true if the player is a computer */
+         int     from_network;  /* true if the player is located on */
+                                /* a remote machine                 */
         } CURSOR;
 /*
 int ACTIVE_FIGHTER[NB_TEAMS];
