@@ -80,8 +80,8 @@ static void exit_all (void)
 /*------------------------------------------------------------------*/
 static void disp_base_message (void)
 {
- log_println_str("Liquid War 5.3.2 by U-Foot.");
- log_println_str("This version released on June 19th 2000.");
+ log_println_str("Liquid War 5.3.3 by U-Foot.");
+ log_println_str("This version released on March 16th 2001.");
  log_println();
  log_println_str("E-mail    : ufoot@ufoot.org");
  log_println_str("Web       : http://www.ufoot.org/liquidwar/");
@@ -231,7 +231,7 @@ void my_exit (int code)
               disp_custom_fail_message();
               break;
         }
-     #ifndef ALLEGRO_LINUX
+     #ifndef ALLEGRO_UNIX
      getch ();
      #endif
 	  log_println();
