@@ -322,7 +322,7 @@ for (i=0;i<NB_TEAMS;++i)
  table=(GLOBAL_CLOCK/3)%2;
  f=CURRENT_ARMY;
 
- #ifndef ALLEGRO_LINUX
+ #ifndef ALLEGRO_UNIX
  if (STARTUP_ASM)
   boost_move_fighters (CURRENT_ARMY,
                        CURRENT_ARMY_SIZE,
