@@ -74,11 +74,11 @@ int set_resolution (int res, int flip)
  #endif
 
  #ifdef ALLEGRO_WINDOWS
-	static int GFX_MODE_TYPE[]={GFX_DIRECTX_AUTODETECT,
-				GFX_DIRECTX_AUTODETECT,
-				GFX_DIRECTX_AUTODETECT,
-				GFX_DIRECTX_AUTODETECT,
-				GFX_DIRECTX_AUTODETECT};
+	static int GFX_MODE_TYPE[]={GFX_AUTODETECT,
+				GFX_AUTODETECT,
+				GFX_AUTODETECT,
+				GFX_AUTODETECT,
+				GFX_AUTODETECT};
 	static int GFX_MODE_W[]={320,512,640,800,1024};
 	static int GFX_MODE_H[]={240,384,480,600,768};
  #endif
@@ -89,8 +89,8 @@ int set_resolution (int res, int flip)
 				GFX_AUTODETECT,
 				GFX_AUTODETECT,
 				GFX_AUTODETECT};
-	static int GFX_MODE_W[]={320,400,640,800,1024};
-	static int GFX_MODE_H[]={240,300,480,600,768};
+	static int GFX_MODE_W[]={320,512,640,800,1024};
+	static int GFX_MODE_H[]={240,384,480,600,768};
  #endif
 
  nb_try=0;
