@@ -62,6 +62,12 @@ int confirm_quit (void)
  #ifdef ALLEGRO_WINDOWS
  d[0].dp="Exit to Windows";
  #endif
+ #ifdef ALLEGRO_UNIX
+ d[0].dp="Exit to Unix";
+ #endif
+ #ifdef ALLEGRO_LINUX
+ d[0].dp="Exit to Linux";
+ #endif
  d[1].dp="Back to LW";
  d[0].key='d';
  d[1].key='w';
